@@ -47,7 +47,7 @@ class TwitchBot(MultiBot[twitchio.Client]):
             channel_id = int(next(iter(await self.client.fetch_users([channel_name])), None).id)
 
         return Chat(
-            platform=self.platform.value,
+            platform=self.platform,
             id=channel_id,
             name=channel_name,
             group_id=channel_id,
@@ -61,7 +61,7 @@ class TwitchBot(MultiBot[twitchio.Client]):
             id = next(iter(await self.client.fetch_users([original_user.name])), None).id
 
         return User(
-            platform=self.platform.value,
+            platform=self.platform,
             id=int(id),
             name=original_user.display_name,
             is_admin=getattr(original_user, 'is_mod', None) if is_admin is None else is_admin,
@@ -141,8 +141,8 @@ class TwitchBot(MultiBot[twitchio.Client]):
             'author': {'$ne': owner_user.object_id},
             'chat': chat.object_id,
             'is_deleted': False,
-            'last_update': {'$gt': datetime.datetime.now(datetime.timezone.utc) - datetime.timedelta(days=1)}
-        }, sort_keys=(('last_update', pymongo.DESCENDING),), lazy=True)
+            'date': {'$gt': datetime.datetime.now(datetime.timezone.utc) - datetime.timedelta(days=1)}
+        }, sort_keys=(('date', pymongo.DESCENDING),), lazy=True)
 
         deleted_message_count = 0
         while deleted_message_count < n_messages:
